import { OpenAPIV3 } from 'openapi-types';
import Ajv, { ValidateFunction } from 'ajv';
import { RequestHandler } from 'express';
export default class PathMiddleware {
    private static instance;
    private validate;
    private readonly operations;
    private validatorQueue;
    private constructor();
    /**
     * Initializes the validation feature for the path middlewares. Must be placed right before starting Express app.
     *
     * @param openApiDoc - Document that is used to validate routes. OperationId's must match pathMiddleware operationIds
     * @param ajv - Ajv client instance - user configured, provided and defined.
     * @throws
     * - If no path middleware have been created (attached to at least one route)
     * - If open api document or ajv instances is missing
     * - If an operationId is not unique
     * - If an operation object on the OpenApiv3 document was not found with one of the operationIds
     */
    static initializeValidation(openApiDoc: OpenAPIV3.Document, ajv: Ajv): void;
    /**
     * Creates a path middleware that attaches to a route, providing meta-data for the express parser to pick up.
     *
     * @param  operationId - Required unique Express App wide id representing this specific operation in the open api schema.
     * @param  param - Object to hold optional parameters
     * @param  param.operationObject - The Open Api operation object for this route.
     * @param  param.validate - Overrides global validation option for this route.
     * @param  param.exclude - Indicates if this route should be marked for exclusion when generating OpenApi documents.
     * @returns An Express middleware object to attach to a route
     * @throws
     * - If operationId is not unique per express app,
     * - If validation is selected and no OpenApi document is provided.
     */
    static path(operationId: string, { operationObject, validate, exclude, }: {
        operationObject?: OpenAPIV3.OperationObject;
        validate?: boolean;
        exclude?: boolean;
    }): RequestHandler;
    private path;
    private initializeValidation;
}
export declare const onlyForTesting: {
    makeValidator: (operationId: string, doc: OpenAPIV3.Document, ajv: Ajv) => ValidateFunction;
    selectOperation: (operationId: string, paths: OpenAPIV3.PathsObject) => OpenAPIV3.OperationObject | undefined;
};
